# termslist.py

alcohol_terms = [
    "alcohol",
    "wine",
    "beer",
    "drink",
    "drinking",
    "drinks",
    "ethanol",
    "etoh",
    "booze",
    "cocktail",
    "drunk",
    "intoxicated",
    "liquor",
    "spirits",
    "hard liquor",
    "alcoholic beverage",
    "bar",
    "pub",
    "alcoholism",
    "alcohol abuse",
    "fermented beverage",
    "alcohol withdrawal",
    "alcohol addiction",
    "DUI (Driving Under the Influence)",
    "alcoholic drink",
    "alchol",
    "alhcohol",
    "alcol",
    "alc-consumption",
    "alcholic",
    "alch",
    "EtOH",
    "alcahol",
    "Et-OH",
    "alcohol use",
    "alcohol use disorder",
]

opioid_terms = [
    "pain med",
    "opioid",
    "opiod",
    "narc",
    "analges",
    "suboxone",
    "Avinza",
    "codeine",
    "dilaudid",
    "fentanyl",
    "hydrocodone",
    "morphine",
    "opana",
    "opiate",
    "oxycodone",
    "oxycontin",
    "oxymorphone",
    "percocet",
    "roxicodone",
    "sufentanyl",
    "vicodin",
    "lortab",
    "hydromorphone",
    "abstral",
    "actiq",
    "alfentanil",
    "arymo",
    "ascomp",
    "astramorph",
    "avinza",
    "belbuca",
    "brompheniramine",
    "bunavail",
    "buprenex",
    "buprenorphine",
    "butalbital",
    "butorphanol",
    "butrans",
    "capcof",
    "carisoprodol",
    "cheratussin",
    "coditussin",
    "conzip",
    "demerol",
    "dexbrompheniramine",
    "dihydrocodeine",
    "diskets",
    "dolophine",
    "durmorph",
    "embeda",
    "endacof",
    "endocet",
    "exalgo",
    "fentora",
    "fioricet",
    "flowtuss",
    "guaifenesin",
    "histex",
    "hycet",
    "hycofenix",
    "hydrocodone",
    "hydromorphone",
    "hysingla",
    "ibudone",
    "infumorph",
    "iophen",
    "iorinal",
    "kadian",
    "lazanda",
    "levorphanol",
    "lorcet",
    "lotruss",
    "meperidine",
    "methadone",
    "methadose",
    "morphabond",
    "morphine",
    "ms contin",
    "nalbuphine",
    "nalocet",
    "ninjacof",
    "nucynta",
    "obredon",
    "opana",
    "opium",
    "orco",
    "oxaydo",
    "oxecta",
    "oxycodone",
    "panlor",
    "paregoric",
    "pentazocine",
    "percocet",
    "phenylhistine",
    "primlev",
    "pro-clear",
    "probuphine",
    "promethazine",
    "psuedoephedrine",
    "relcof",
    "remifentanil",
    "reprexain",
    "rezira",
    "robafen",
    "roxicodone",
    "rydex",
    "suboxone",
    "subsys",
    "sufentanil",
    "synalgos",
    "talwin",
    "tapentado",
    "tramadol",
    "trezix",
    "triplidine",
    "trymine",
    "tusnel",
    "tussicpas",
    "ultiva",
    "ultracet",
    "ultram",
    "verdrocet",
    "vicodin",
    "vicoprofen",
    "virtussin",
    "xartemix",
    "xodol",
    "xtampza",
    "zamicet",
    "zodryl",
    "zubsolv",
    "zutripro",
    "zylon",
]

chronic_pain_terms = [
    "chronic pain",
    "persistent pain",
    "long-term pain",
    "fibromyalgia",
    "neuropathy",
    "back pain",
    "arthritis",
    "migraine",
    "headache",
    "neck pain",
    "sciatica",
    "joint pain",
    "nerve pain",
    "inflammatory pain",
]

termslist = {
    "alcohol_terms": alcohol_terms,
    "opioid_terms": opioid_terms,
    "chronic_pain_terms": chronic_pain_terms,
}
